@@ -30,16 +30,13 @@
 #include "misc.h"
 #include "setting.h"
 
-/* TODO: Use G_DEFINE_TYPE_WITH_PRIVATE. */
-G_DEFINE_TYPE (EtApplication, et_application, GTK_TYPE_APPLICATION)
-
-#define et_application_get_instance_private(app) (app->priv)
-
-struct _EtApplicationPrivate
+typedef struct
 {
     guint idle_handler;
     gchar *init_directory;
-};
+} EtApplicationPrivate;
+
+G_DEFINE_TYPE_WITH_PRIVATE (EtApplication, et_application, GTK_TYPE_APPLICATION)
 
 static const GOptionEntry entries[] =
 {
@@ -73,11 +70,7 @@ on_about (GSimpleAction *action,
           GVariant *parameter,
           gpointer user_data)
 {
-    GList *windows;
-
-    windows = gtk_application_get_windows (GTK_APPLICATION (user_data));
-
-    et_show_about_dialog (windows->data);
+    et_show_about_dialog (gtk_application_get_active_window (GTK_APPLICATION (user_data)));
 }
 
 static void
@@ -85,11 +78,7 @@ on_quit (GSimpleAction *action,
          GVariant *parameter,
          gpointer user_data)
 {
-    GList *windows;
-
-    windows = gtk_application_get_windows (GTK_APPLICATION (user_data));
-
-    et_application_window_quit (windows->data);
+    et_application_window_quit (ET_APPLICATION_WINDOW (gtk_application_get_active_window (GTK_APPLICATION (user_data))));
 }
 
 static const GActionEntry actions[] =
@@ -273,13 +262,13 @@ check_for_hidden_path_in_tree (GFile *arg)
 static void
 et_application_activate (GApplication *application)
 {
-    GList *windows;
+    GtkWindow *window;
 
-    windows = gtk_application_get_windows (GTK_APPLICATION (application));
+    window = gtk_application_get_active_window (GTK_APPLICATION (application));
 
-    if (windows != NULL)
+    if (window != NULL)
     {
-        gtk_window_present (windows->data);
+        gtk_window_present (window);
     }
     else
     {
@@ -400,7 +389,7 @@ et_application_open (GApplication *self,
                      const gchar *hint)
 {
     EtApplicationPrivate *priv;
-    GList *windows;
+    GtkWindow *window;
     gboolean activated;
     GFile *arg;
     GFile *parent;
@@ -412,8 +401,8 @@ et_application_open (GApplication *self,
 
     priv = et_application_get_instance_private (ET_APPLICATION (self));
 
-    windows = gtk_application_get_windows (GTK_APPLICATION (self));
-    activated = windows ? TRUE : FALSE;
+    window = gtk_application_get_active_window (GTK_APPLICATION (self));
+    activated = window ? TRUE : FALSE;
 
     /* Only take the first file; ignore the rest. */
     arg = files[0];
@@ -451,7 +440,8 @@ et_application_open (GApplication *self,
     {
         if (activated)
         {
-            et_application_window_select_dir (windows->data, path);
+            et_application_window_select_dir (ET_APPLICATION_WINDOW (window),
+                                              path);
             g_free (path);
         }
         else
@@ -477,7 +467,7 @@ et_application_open (GApplication *self,
                 gchar *parent_path;
 
                 parent_path = g_file_get_path (arg);
-                et_application_window_select_dir (windows->data,
+                et_application_window_select_dir (ET_APPLICATION_WINDOW (window),
                                                   parent_path);
 
                 g_free (parent_path);
@@ -532,7 +522,6 @@ static void
 et_application_startup (GApplication *application)
 {
     GtkBuilder *builder;
-    GError *error = NULL;
     GMenuModel *appmenu;
     GMenuModel *menubar;
 
@@ -543,14 +532,7 @@ et_application_startup (GApplication *application)
 
     /* gtk_init() calls setlocale(), so gettext must be called after that. */
     g_set_application_name (_(PACKAGE_NAME));
-    builder = gtk_builder_new ();
-    gtk_builder_add_from_resource (builder, "/org/gnome/EasyTAG/menus.ui",
-                                   &error);
-
-    if (error != NULL)
-    {
-        g_error ("Unable to get app menu from resource: %s", error->message);
-    }
+    builder = gtk_builder_new_from_resource ("/org/gnome/EasyTAG/menus.ui");
 
     appmenu = G_MENU_MODEL (gtk_builder_get_object (builder, "app-menu"));
     gtk_application_set_app_menu (GTK_APPLICATION (application), appmenu);
@@ -596,8 +578,6 @@ et_application_finalize (GObject *object)
 static void
 et_application_init (EtApplication *self)
 {
-    self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, ET_TYPE_APPLICATION,
-                                              EtApplicationPrivate);
 }
 
 static void
@@ -616,8 +596,6 @@ et_application_class_init (EtApplicationClass *klass)
     gapplication_class->open = et_application_open;
     gapplication_class->shutdown = et_application_shutdown;
     gapplication_class->startup = et_application_startup;
-
-    g_type_class_add_private (klass, sizeof (EtApplicationPrivate));
 }
 
 /*
