@@ -60,12 +60,7 @@
 #include "wavpack_header.h"
 #endif
 
-/* TODO: Use G_DEFINE_TYPE_WITH_PRIVATE. */
-G_DEFINE_TYPE (EtApplicationWindow, et_application_window, GTK_TYPE_APPLICATION_WINDOW)
-
-#define et_application_window_get_instance_private(window) (window->priv)
-
-struct _EtApplicationWindowPrivate
+typedef struct
 {
     GtkWidget *browser;
 
@@ -90,7 +85,9 @@ struct _EtApplicationWindowPrivate
     gboolean is_maximized;
     gint height;
     gint width;
-};
+} EtApplicationWindowPrivate;
+
+G_DEFINE_TYPE_WITH_PRIVATE (EtApplicationWindow, et_application_window, GTK_TYPE_APPLICATION_WINDOW)
 
 /* Used to force to hide the msgbox when deleting file */
 static gboolean SF_HideMsgbox_Delete_File;
@@ -1617,16 +1614,7 @@ et_application_window_init (EtApplicationWindow *self)
     GtkWidget *hbox;
     GtkWidget *grid;
 
-    priv = self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self,
-                                                     ET_TYPE_APPLICATION_WINDOW,
-                                                     EtApplicationWindowPrivate);
-
-    priv->cddb_dialog = NULL;
-    priv->load_files_dialog = NULL;
-    priv->playlist_dialog = NULL;
-    priv->preferences_dialog = NULL;
-    priv->scan_dialog = NULL;
-    priv->search_dialog = NULL;
+    priv = et_application_window_get_instance_private (self);
 
     g_action_map_add_action_entries (G_ACTION_MAP (self), actions,
                                      G_N_ELEMENTS (actions), self);
@@ -1665,32 +1653,13 @@ et_application_window_init (EtApplicationWindow *self)
     /* Menu bar and tool bar. */
     {
         GtkBuilder *builder;
-        GError *error = NULL;
         GtkWidget *toolbar;
-        GtkToolButton *button;
 
-        builder = gtk_builder_new ();
-        gtk_builder_add_from_resource (builder,
-                                       "/org/gnome/EasyTAG/toolbar.ui",
-                                       &error);
-
-        if (error != NULL)
-        {
-            g_error ("Unable to get toolbar from resource: %s",
-                     error->message);
-        }
+        builder = gtk_builder_new_from_resource ("/org/gnome/EasyTAG/toolbar.ui");
 
         toolbar = GTK_WIDGET (gtk_builder_get_object (builder, "main_toolbar"));
         gtk_box_pack_start (GTK_BOX (main_vbox), toolbar, FALSE, FALSE, 0);
 
-        /* TODO: Use resource property on GtkImage when using GTK+ > 3.8. */
-        button = GTK_TOOL_BUTTON (gtk_builder_get_object (builder, "artist_view_button"));
-        gtk_tool_button_set_icon_widget (button,
-                                         gtk_image_new_from_resource ("/org/gnome/EasyTAG/images/artist.png"));
-        button = GTK_TOOL_BUTTON (gtk_builder_get_object (builder, "invert_selection_button"));
-        gtk_tool_button_set_icon_widget (button,
-                                         gtk_image_new_from_resource ("/org/gnome/EasyTAG/images/invert-selection.png"));
-
         g_object_unref (builder);
     }
 
@@ -1754,8 +1723,6 @@ static void
 et_application_window_class_init (EtApplicationWindowClass *klass)
 {
     G_OBJECT_CLASS (klass)->dispose = et_application_window_dispose;
-
-    g_type_class_add_private (klass, sizeof (EtApplicationWindowPrivate));
 }
 
 /*
