@@ -65,9 +65,65 @@
  * of any language.
  */
 
-static gboolean Flac_Write_Delimetered_Tag (FLAC__StreamMetadata *vc_block, const gchar *tag_name, gchar *values);
-static gboolean Flac_Write_Tag (FLAC__StreamMetadata *vc_block, const gchar *tag_name, gchar *value);
-static gboolean Flac_Set_Tag (FLAC__StreamMetadata *vc_block, const gchar *tag_name, gchar *value, gboolean split);
+/*
+ * validate_field_utf8:
+ * @field_value: the string to validate
+ * @field_len: the length of the string
+ *
+ * Validate a Vorbis comment field to ensure that it is UTF-8. Either return a
+ * duplicate of the original (valid) string, or a converted equivalent (of an
+ * invalid UTF-8 string).
+ *
+ * Returns: a valid UTF-8 represenation of @field_value
+ */
+static gchar *
+validate_field_utf8 (const gchar *field_value,
+                     guint32 field_len)
+{
+    gchar *result;
+
+    if (g_utf8_validate (field_value, field_len, NULL))
+    {
+        result = g_strndup (field_value, field_len);
+    }
+    else
+    {
+        gchar *field_value_tmp = g_strndup (field_value,
+                                            field_len);
+        /* Unnecessarily validates the field again, but this should not be the
+         * common case. */
+        result = Try_To_Validate_Utf8_String (field_value_tmp);
+        g_free (field_value_tmp);
+    }
+
+    return result;
+}
+
+/*
+ * set_or_append_field:
+ * @field: (inout): pointer to a location in which to store the field value
+ * @field_value: (transfer full): the string to store in @field
+ *
+ * Set @field to @field_value if @field is empty, otherwise append to it.
+ * Ownership of @field_value is transferred to this function.
+ */
+static void
+set_or_append_field (gchar **field,
+                     gchar *field_value)
+{
+    if (*field == NULL)
+    {
+        *field = field_value;
+    }
+    else
+    {
+        gchar *field_tmp = g_strconcat (*field, MULTIFIELD_SEPARATOR,
+                                        field_value, NULL);
+        g_free (*field);
+        *field = field_tmp;
+        g_free (field_value);
+    }
+}
 
 /*
  * Read tag data from a FLAC file using the level 2 flac interface,
@@ -142,9 +198,8 @@ flac_tag_read_file_tag (GFile *file,
                 FLAC__StreamMetadata_VorbisComment       *vc;
                 FLAC__StreamMetadata_VorbisComment_Entry *field;
                 gint   field_num;
-                gint   field_len;
+                guint32 field_len;
                 gchar *field_value;
-                gchar *field_value_tmp;
                 
                 // Get comments from block
                 vc = &block->data.vorbis_comment;
@@ -166,14 +221,10 @@ flac_tag_read_file_tag (GFile *file,
                         if (!et_str_empty (field_value))
                         {
                             field_len = field->length - (field_value - (gchar*) field->entry);
-                            field_value_tmp = g_strndup(field_value, field_len);
-                            field_value = Try_To_Validate_Utf8_String(field_value_tmp);
-                            g_free(field_value_tmp);
-                            if (FileTag->title==NULL)
-                                FileTag->title = g_strdup(field_value);
-                            else
-                                FileTag->title = g_strconcat(FileTag->title,MULTIFIELD_SEPARATOR,field_value,NULL);
-                            g_free(field_value);
+                            field_value = validate_field_utf8 (field_value,
+                                                               field_len);
+
+                            set_or_append_field (&FileTag->title, field_value);
                         }
                     }
                 }
@@ -195,14 +246,11 @@ flac_tag_read_file_tag (GFile *file,
                         if (!et_str_empty (field_value))
                         {
                             field_len = field->length - (field_value - (gchar*) field->entry);
-                            field_value_tmp = g_strndup(field_value, field_len);
-                            field_value = Try_To_Validate_Utf8_String(field_value_tmp);
-                            g_free(field_value_tmp);
-                            if (FileTag->artist==NULL)
-                                FileTag->artist = g_strdup(field_value);
-                            else
-                                FileTag->artist = g_strconcat(FileTag->artist,MULTIFIELD_SEPARATOR,field_value,NULL);
-                            g_free(field_value);
+                            field_value = validate_field_utf8 (field_value,
+                                                               field_len);
+
+                            set_or_append_field (&FileTag->artist,
+                                                 field_value);
                         }
                     }
                 }
@@ -224,14 +272,11 @@ flac_tag_read_file_tag (GFile *file,
                         if (!et_str_empty (field_value))
                         {
                             field_len = field->length - (field_value - (gchar*) field->entry);
-                            field_value_tmp = g_strndup(field_value, field_len);
-                            field_value = Try_To_Validate_Utf8_String(field_value_tmp);
-                            g_free(field_value_tmp);
-                            if (FileTag->album_artist==NULL)
-                                FileTag->album_artist = g_strdup(field_value);
-                            else
-                                FileTag->album_artist = g_strconcat(FileTag->album_artist,MULTIFIELD_SEPARATOR,field_value,NULL);
-                            g_free(field_value);
+                            field_value = validate_field_utf8 (field_value,
+                                                               field_len);
+
+                            set_or_append_field (&FileTag->album_artist,
+                                                 field_value);
                         }
                     }
                 }
@@ -253,14 +298,10 @@ flac_tag_read_file_tag (GFile *file,
                         if (!et_str_empty (field_value))
                         {
                             field_len = field->length - (field_value - (gchar*) field->entry);
-                            field_value_tmp = g_strndup(field_value, field_len);
-                            field_value = Try_To_Validate_Utf8_String(field_value_tmp);
-                            g_free(field_value_tmp);
-                            if (FileTag->album==NULL)
-                                FileTag->album = g_strdup(field_value);
-                            else
-                                FileTag->album = g_strconcat(FileTag->album,MULTIFIELD_SEPARATOR,field_value,NULL);
-                            g_free(field_value);
+                            field_value = validate_field_utf8 (field_value,
+                                                               field_len);
+
+                            set_or_append_field (&FileTag->album, field_value);
                         }
                     }
                 }
@@ -281,11 +322,8 @@ flac_tag_read_file_tag (GFile *file,
                         if (!et_str_empty (field_value))
                         {
                             field_len = field->length - (field_value - (gchar*) field->entry);
-                            field_value_tmp = g_strndup (field_value,
-                                                         field_len);
-                            field_value = Try_To_Validate_Utf8_String (field_value_tmp);
-                            g_free (field_value_tmp);
-
+                            field_value = validate_field_utf8 (field_value,
+                                                               field_len);
                             FileTag->disc_total = et_disc_number_to_string (atoi (field_value));
                             g_free (field_value);
                         }
@@ -306,9 +344,8 @@ flac_tag_read_file_tag (GFile *file,
                         if (!et_str_empty (field_value))
                         {
                             field_len = field->length - (field_value - (gchar*) field->entry);
-                            field_value_tmp = g_strndup(field_value, field_len);
-                            field_value = Try_To_Validate_Utf8_String(field_value_tmp);
-                            g_free(field_value_tmp);
+                            field_value = validate_field_utf8 (field_value,
+                                                               field_len);
                             string = g_utf8_strchr (field_value, -1, '/');
 
                             if (string && !FileTag->disc_total)
@@ -340,9 +377,8 @@ flac_tag_read_file_tag (GFile *file,
                         if (!et_str_empty (field_value))
                         {
                             field_len = field->length - (field_value - (gchar*) field->entry);
-                            field_value_tmp = g_strndup(field_value, field_len);
-                            field_value = Try_To_Validate_Utf8_String(field_value_tmp);
-                            g_free(field_value_tmp);
+                            field_value = validate_field_utf8 (field_value,
+                                                               field_len);
                             FileTag->year = field_value;
                         }
                     }
@@ -364,12 +400,10 @@ flac_tag_read_file_tag (GFile *file,
                         if (!et_str_empty (field_value))
                         {
                             field_len = field->length - (field_value - (gchar*) field->entry);
-                            field_value_tmp = g_strndup(field_value, field_len);
-                            field_value = Try_To_Validate_Utf8_String(field_value_tmp);
-                            g_free(field_value_tmp);
-
+                            field_value = validate_field_utf8 (field_value,
+                                                               field_len);
                             FileTag->track_total = et_track_number_to_string (atoi (field_value));
-                            g_free(field_value);
+                            g_free (field_value);
                         }
                     }
                     // Below is also filled track_total if not done here
@@ -388,9 +422,8 @@ flac_tag_read_file_tag (GFile *file,
                         if (!et_str_empty (field_value))
                         {
                             field_len = field->length - (field_value - (gchar*) field->entry);
-                            field_value_tmp = g_strndup(field_value, field_len);
-                            field_value = Try_To_Validate_Utf8_String(field_value_tmp);
-                            g_free(field_value_tmp);
+                            field_value = validate_field_utf8 (field_value,
+                                                               field_len);
                             string = g_utf8_strchr(field_value, -1, '/');
 
                             if (string && !FileTag->track_total)
@@ -400,7 +433,7 @@ flac_tag_read_file_tag (GFile *file,
                             }
                             FileTag->track = et_track_number_to_string (atoi (field_value));
 
-                            g_free(field_value);
+                            g_free (field_value);
                         }
                     }
                 }
@@ -422,14 +455,10 @@ flac_tag_read_file_tag (GFile *file,
                         if (!et_str_empty (field_value))
                         {
                             field_len = field->length - (field_value - (gchar*) field->entry);
-                            field_value_tmp = g_strndup(field_value, field_len);
-                            field_value = Try_To_Validate_Utf8_String(field_value_tmp);
-                            g_free(field_value_tmp);
-                            if (FileTag->genre==NULL)
-                                FileTag->genre = g_strdup(field_value);
-                            else
-                                FileTag->genre = g_strconcat(FileTag->genre,MULTIFIELD_SEPARATOR,field_value,NULL);
-                            g_free(field_value);
+                            field_value = validate_field_utf8 (field_value,
+                                                               field_len);
+
+                            set_or_append_field (&FileTag->genre, field_value);
                         }
                     }
                 }
@@ -471,14 +500,11 @@ flac_tag_read_file_tag (GFile *file,
                         if (!et_str_empty (field_value))
                         {
                             field_len = field->length - (field_value - (gchar*) field->entry);
-                            field_value_tmp = g_strndup(field_value, field_len);
-                            field_value = Try_To_Validate_Utf8_String(field_value_tmp);
-                            g_free(field_value_tmp);
-                            if (FileTag->comment==NULL)
-                                FileTag->comment = g_strdup(field_value);
-                            else
-                                FileTag->comment = g_strconcat(FileTag->comment,MULTIFIELD_SEPARATOR,field_value,NULL);
-                            g_free(field_value);
+                            field_value = validate_field_utf8 (field_value,
+                                                               field_len);
+
+                            set_or_append_field (&FileTag->comment,
+                                                 field_value);
                         }
                     }
                 }
@@ -500,14 +526,11 @@ flac_tag_read_file_tag (GFile *file,
                         if (!et_str_empty (field_value))
                         {
                             field_len = field->length - (field_value - (gchar*) field->entry);
-                            field_value_tmp = g_strndup(field_value, field_len);
-                            field_value = Try_To_Validate_Utf8_String(field_value_tmp);
-                            g_free(field_value_tmp);
-                            if (FileTag->composer==NULL)
-                                FileTag->composer = g_strdup(field_value);
-                            else
-                                FileTag->composer = g_strconcat(FileTag->composer,MULTIFIELD_SEPARATOR,field_value,NULL);
-                            g_free(field_value);
+                            field_value = validate_field_utf8 (field_value,
+                                                               field_len);
+
+                            set_or_append_field (&FileTag->composer,
+                                                 field_value);
                         }
                     }
                 }
@@ -529,14 +552,11 @@ flac_tag_read_file_tag (GFile *file,
                         if (!et_str_empty (field_value))
                         {
                             field_len = field->length - (field_value - (gchar*) field->entry);
-                            field_value_tmp = g_strndup(field_value, field_len);
-                            field_value = Try_To_Validate_Utf8_String(field_value_tmp);
-                            g_free(field_value_tmp);
-                            if (FileTag->orig_artist==NULL)
-                                FileTag->orig_artist = g_strdup(field_value);
-                            else
-                                FileTag->orig_artist = g_strconcat(FileTag->orig_artist,MULTIFIELD_SEPARATOR,field_value,NULL);
-                            g_free(field_value);
+                            field_value = validate_field_utf8 (field_value,
+                                                               field_len);
+
+                            set_or_append_field (&FileTag->orig_artist,
+                                                 field_value);
                         }
                     }
                 }
@@ -558,14 +578,11 @@ flac_tag_read_file_tag (GFile *file,
                         if (!et_str_empty (field_value))
                         {
                             field_len = field->length - (field_value - (gchar*) field->entry);
-                            field_value_tmp = g_strndup(field_value, field_len);
-                            field_value = Try_To_Validate_Utf8_String(field_value_tmp);
-                            g_free(field_value_tmp);
-                            if (FileTag->copyright==NULL)
-                                FileTag->copyright = g_strdup(field_value);
-                            else
-                                FileTag->copyright = g_strconcat(FileTag->copyright,MULTIFIELD_SEPARATOR,field_value,NULL);
-                            g_free(field_value);
+                            field_value = validate_field_utf8 (field_value,
+                                                               field_len);
+
+                            set_or_append_field (&FileTag->copyright,
+                                                 field_value);
                         }
                     }
                 }
@@ -587,14 +604,10 @@ flac_tag_read_file_tag (GFile *file,
                         if (!et_str_empty (field_value))
                         {
                             field_len = field->length - (field_value - (gchar*) field->entry);
-                            field_value_tmp = g_strndup(field_value, field_len);
-                            field_value = Try_To_Validate_Utf8_String(field_value_tmp);
-                            g_free(field_value_tmp);
-                            if (FileTag->url==NULL)
-                                FileTag->url = g_strdup(field_value);
-                            else
-                                FileTag->url = g_strconcat(FileTag->url,MULTIFIELD_SEPARATOR,field_value,NULL);
-                            g_free(field_value);
+                            field_value = validate_field_utf8 (field_value,
+                                                               field_len);
+
+                            set_or_append_field (&FileTag->url, field_value);
                         }
                     }
                 }
@@ -616,14 +629,11 @@ flac_tag_read_file_tag (GFile *file,
                         if (!et_str_empty (field_value))
                         {
                             field_len = field->length - (field_value - (gchar*) field->entry);
-                            field_value_tmp = g_strndup(field_value, field_len);
-                            field_value = Try_To_Validate_Utf8_String(field_value_tmp);
-                            g_free(field_value_tmp);
-                            if (FileTag->encoded_by==NULL)
-                                FileTag->encoded_by = g_strdup(field_value);
-                            else
-                                FileTag->encoded_by = g_strconcat(FileTag->encoded_by,MULTIFIELD_SEPARATOR,field_value,NULL);
-                            g_free(field_value);
+                            field_value = validate_field_utf8 (field_value,
+                                                               field_len);
+
+                            set_or_append_field (&FileTag->encoded_by,
+                                                 field_value);
                         }
                     }
                 }
@@ -741,51 +751,92 @@ flac_tag_read_file_tag (GFile *file,
     return TRUE;
 }
 
-
-
 /*
- * Save field value in separated tags if it contains multifields
+ * vc_block_append_single_tag:
+ * @vc_block: the Vorbis comment in which to add the tag
+ * @tag_name: the name of the tag
+ * @value: the value of the tag
+ *
+ * Save field value in a single tag.
  */
-static gboolean Flac_Write_Delimetered_Tag (FLAC__StreamMetadata *vc_block, const gchar *tag_name, gchar *values)
-{
-    gchar **strings = g_strsplit(values,MULTIFIELD_SEPARATOR,255);
-    unsigned int i=0;
-    
-    for (i=0;i<g_strv_length(strings);i++)
-    {
-        if (strlen(strings[i])>0)
-        {
-            Flac_Write_Tag(vc_block, tag_name, strings[i]);
-        }
-    }
-    g_strfreev(strings);
-    return TRUE;
-}
-
-/*
- * Save field value in a single tag
- */
-static gboolean Flac_Write_Tag (FLAC__StreamMetadata *vc_block, const gchar *tag_name, gchar *value)
+static void
+vc_block_append_single_tag (FLAC__StreamMetadata *vc_block,
+                            const gchar *tag_name,
+                            const gchar *value)
 {
     FLAC__StreamMetadata_VorbisComment_Entry field;
-    char *string = g_strconcat(tag_name,value,NULL);
+    char *string = g_strconcat (tag_name, value, NULL);
+    FLAC__bool result;
 
     field.entry = (FLAC__byte *)string;
-    field.length = strlen(string); // Warning : g_utf8_strlen doesn't count the multibyte characters. Here we need the allocated size.
-    FLAC__metadata_object_vorbiscomment_insert_comment(vc_block,vc_block->data.vorbis_comment.num_comments,field,true);
-    g_free(string);
-    return TRUE;
+    field.length = strlen (string);
+    result = FLAC__metadata_object_vorbiscomment_append_comment (vc_block,
+                                                                 field, true);
+    g_free (string);
+
+    if (result != true)
+    {
+        g_critical ("Invalid Vorbis comment, or memory allocation failed, when writing FLAC tag '%s' with value '%s'",
+                    tag_name, value);
+    }
 }
 
-static gboolean Flac_Set_Tag (FLAC__StreamMetadata *vc_block, const gchar *tag_name, gchar *value, gboolean split)
+/*
+ * vc_block_append_multiple_tags:
+ * @vc_block: the Vorbis comment block to which tags should be appended
+ * @tag_name: the name of the tag
+ * @values: the values of the tag
+ *
+ * Append multiple copies of the supplied @tag_name to @vc_block, splitting
+ * @values at %MULTIFIELD_SEPARATOR.
+ */
+static void
+vc_block_append_multiple_tags (FLAC__StreamMetadata *vc_block,
+                               const gchar *tag_name,
+                               const gchar *values)
 {
-    if ( value && split ) {
-        return Flac_Write_Delimetered_Tag(vc_block,tag_name,value);
-    } else if ( value ) {
-        return Flac_Write_Tag(vc_block,tag_name,value);
+    gchar **strings = g_strsplit (values, MULTIFIELD_SEPARATOR, 255);
+    guint i;
+    guint len;
+    
+    for (i = 0, len = g_strv_length (strings); i < len; i++)
+    {
+        if (!et_str_empty (strings[i]))
+        {
+            vc_block_append_single_tag (vc_block, tag_name, strings[i]);
+        }
     }
 
-    return FALSE;
+    g_strfreev (strings);
+}
+
+/*
+ * vc_block_append_tag:
+ * @vc_block: the Vorbis comment block to which a tag should be appended
+ * @tag_name: the name of the tag, including the trailing '=', or the empty
+ *            string (if @value is to be taken as the combination of the tag
+ *            name and value)
+ * @value: the value of the tag
+ * @split: %TRUE to split @value into multiple tags at %MULTIFIELD_SEPARATOR,
+ *         %FALSE to keep the tag value unchanged
+ *
+ * Append the supplied @tag_name and @value to @vc_block, optionally splitting
+ * @value if @split is %TRUE.
+ */
+static void
+vc_block_append_tag (FLAC__StreamMetadata *vc_block,
+                     const gchar *tag_name,
+                     const gchar *value,
+                     gboolean split)
+{
+    if (value && split)
+    {
+        vc_block_append_multiple_tags (vc_block, tag_name, value);
+    }
+    else if (value)
+    {
+        vc_block_append_single_tag (vc_block, tag_name, value);
+    }
 }
 
 /*
@@ -939,90 +990,95 @@ flac_tag_write_file_tag (const ET_File *ETFile,
         /*********
          * Title *
          *********/
-        Flac_Set_Tag (vc_block, "TITLE=", FileTag->title,
-                      g_settings_get_boolean (MainSettings,
-                                              "ogg-split-title"));
+        vc_block_append_tag (vc_block, "TITLE=", FileTag->title,
+                             g_settings_get_boolean (MainSettings,
+                                                     "ogg-split-title"));
 
         /**********
          * Artist *
          **********/
-        Flac_Set_Tag (vc_block, "ARTIST=", FileTag->artist,
-                      g_settings_get_boolean (MainSettings,
-                                              "ogg-split-artist"));
+        vc_block_append_tag (vc_block, "ARTIST=", FileTag->artist,
+                             g_settings_get_boolean (MainSettings,
+                                                     "ogg-split-artist"));
 
         /****************
          * Album Artist *
          ****************/
-        Flac_Set_Tag (vc_block, "ALBUMARTIST=", FileTag->album_artist,
-                      g_settings_get_boolean (MainSettings,
-                                              "ogg-split-artist"));
+        vc_block_append_tag (vc_block, "ALBUMARTIST=", FileTag->album_artist,
+                             g_settings_get_boolean (MainSettings,
+                                                     "ogg-split-artist"));
 
         /*********
          * Album *
          *********/
-        Flac_Set_Tag (vc_block, "ALBUM=", FileTag->album,
-                      g_settings_get_boolean (MainSettings,
-                                              "ogg-split-album"));
+        vc_block_append_tag (vc_block, "ALBUM=", FileTag->album,
+                             g_settings_get_boolean (MainSettings,
+                                                     "ogg-split-album"));
 
         /******************************
          * Disc Number and Disc Total *
          ******************************/
-        Flac_Set_Tag (vc_block, "DISCNUMBER=", FileTag->disc_number, FALSE);
-        Flac_Set_Tag (vc_block, "DISCTOTAL=", FileTag->disc_total, FALSE);
+        vc_block_append_tag (vc_block, "DISCNUMBER=", FileTag->disc_number,
+                             FALSE);
+        vc_block_append_tag (vc_block, "DISCTOTAL=", FileTag->disc_total,
+                             FALSE);
 
         /********
          * Year *
          ********/
-        Flac_Set_Tag(vc_block,"DATE=",FileTag->year,FALSE);
+        vc_block_append_tag (vc_block, "DATE=", FileTag->year, FALSE);
 
         /*************************
          * Track and Total Track *
          *************************/
-        Flac_Set_Tag(vc_block,"TRACKNUMBER=",FileTag->track,FALSE);
-        Flac_Set_Tag(vc_block,"TRACKTOTAL=",FileTag->track_total,FALSE);
+        vc_block_append_tag (vc_block, "TRACKNUMBER=", FileTag->track, FALSE);
+        vc_block_append_tag (vc_block, "TRACKTOTAL=", FileTag->track_total,
+                             FALSE);
 
         /*********
          * Genre *
          *********/
-        Flac_Set_Tag (vc_block, "GENRE=", FileTag->genre,
-                      g_settings_get_boolean (MainSettings,
-                                              "ogg-split-genre"));
+        vc_block_append_tag (vc_block, "GENRE=", FileTag->genre,
+                             g_settings_get_boolean (MainSettings,
+                                                     "ogg-split-genre"));
 
         /***********
          * Comment *
          ***********/
-        Flac_Set_Tag (vc_block, "DESCRIPTION=", FileTag->comment,
-                      g_settings_get_boolean (MainSettings,
-                                              "ogg-split-comment"));
+        vc_block_append_tag (vc_block, "DESCRIPTION=", FileTag->comment,
+                             g_settings_get_boolean (MainSettings,
+                                                     "ogg-split-comment"));
 
         /************
          * Composer *
          ************/
-        Flac_Set_Tag (vc_block, "COMPOSER=", FileTag->composer,
-                      g_settings_get_boolean (MainSettings,
-                                              "ogg-split-composer"));
+        vc_block_append_tag (vc_block, "COMPOSER=", FileTag->composer,
+                             g_settings_get_boolean (MainSettings,
+                                                     "ogg-split-composer"));
 
         /*******************
          * Original artist *
          *******************/
-        Flac_Set_Tag (vc_block, "PERFORMER=", FileTag->orig_artist,
-                      g_settings_get_boolean (MainSettings,
-                                              "ogg-split-original-artist"));
+        vc_block_append_tag (vc_block, "PERFORMER=", FileTag->orig_artist,
+                             g_settings_get_boolean (MainSettings,
+                                                     "ogg-split-original-artist"));
 
         /*************
          * Copyright *
          *************/
-        Flac_Set_Tag(vc_block,"COPYRIGHT=",FileTag->copyright,FALSE);
+        vc_block_append_tag (vc_block, "COPYRIGHT=", FileTag->copyright,
+                             FALSE);
 
         /*******
          * URL *
          *******/
-        Flac_Set_Tag (vc_block, "CONTACT=", FileTag->url, FALSE);
+        vc_block_append_tag (vc_block, "CONTACT=", FileTag->url, FALSE);
 
         /**************
          * Encoded by *
          **************/
-        Flac_Set_Tag(vc_block,"ENCODED-BY=",FileTag->encoded_by,FALSE);
+        vc_block_append_tag (vc_block, "ENCODED-BY=", FileTag->encoded_by,
+                             FALSE);
 
 
         /**************************
@@ -1030,7 +1086,7 @@ flac_tag_write_file_tag (const ET_File *ETFile,
          **************************/
         for (l = FileTag->other; l != NULL; l = g_list_next (l))
         {
-            Flac_Set_Tag (vc_block, "", (gchar *)l->data, FALSE);
+            vc_block_append_tag (vc_block, "", (gchar *)l->data, FALSE);
         }
 
         // Add the block to the the chain (so we don't need to free the block)
