@@ -954,17 +954,12 @@ ogg_tag_write_file_tag (const ET_File *ETFile,
         if (format != PICTURE_FORMAT_PNG && format != PICTURE_FORMAT_JPEG)
         {
             GdkPixbufLoader *loader;
-            gconstpointer old_data;
-            gsize old_data_size;
             GError *loader_error = NULL;
 
             loader = gdk_pixbuf_loader_new ();
 
-            old_data = g_bytes_get_data (pic->bytes, &old_data_size);
-
-            /* TODO: Use gdk_pixbuf_loader_write_bytes() */
-            if (!gdk_pixbuf_loader_write (loader, old_data, old_data_size,
-                                          &loader_error))
+            if (!gdk_pixbuf_loader_write_bytes (loader, pic->bytes,
+                                                &loader_error))
             {
                 g_debug ("Error parsing image data: %s",
                          loader_error->message);
